@@ -21,6 +21,7 @@ import testtools
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests import utils
 
@@ -39,19 +40,17 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
         super(ManageNFSShareNegativeTest, cls).skip_checks()
         if not CONF.share.run_manage_unmanage_tests:
             raise cls.skipException('Manage/unmanage tests are disabled.')
-
-    @classmethod
-    def resource_setup(cls):
         if cls.protocol not in CONF.share.enable_protocols:
             message = "%s tests are disabled" % cls.protocol
             raise cls.skipException(message)
 
         utils.skip_if_manage_not_supported_for_version()
 
+    @classmethod
+    def resource_setup(cls):
         super(ManageNFSShareNegativeTest, cls).resource_setup()
-
         # Create share type
-        cls.st_name = data_utils.rand_name("manage-st-name")
+        cls.st_name = data_utils.rand_name(name="manage-st-name")
         cls.extra_specs = {
             'storage_protocol': CONF.share.capability_storage_protocol,
             'driver_handles_share_servers': CONF.share.multitenancy_enabled,
@@ -67,9 +66,9 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
                                state=constants.STATUS_AVAILABLE):
         # Manage the share and wait for the expected state.
         # Return the managed share object.
-        managed_share = self.shares_v2_client.manage_share(**params)
-        self.shares_v2_client.wait_for_share_status(
-            managed_share['id'], state)
+        managed_share = self.shares_v2_client.manage_share(**params)['share']
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, managed_share['id'], state)
 
         return managed_share
 
@@ -83,7 +82,8 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
             valid_params['share_server_id'] = share['share_server_id']
 
         if utils.is_microversion_ge(CONF.share.max_api_microversion, "2.9"):
-            el = self.shares_v2_client.list_share_export_locations(share["id"])
+            el = self.shares_v2_client.list_share_export_locations(
+                share["id"])['export_locations']
             valid_params['export_path'] = el[0]['path']
 
         if invalid_params:
@@ -156,7 +156,8 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
         self._unmanage_share_and_wait(share)
 
         for invalid_key, invalid_value in (
-            ('export_path', 'invalid_export'),
+            ('export_path',
+             data_utils.rand_name(name='invalid-share-export')),
             ('protocol', 'invalid_protocol'),
         ):
 
@@ -168,9 +169,10 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
             # and leave it in manage_error state
             invalid_share = self.shares_v2_client.manage_share(
                 **invalid_params
-            )
-            self.shares_v2_client.wait_for_share_status(
-                invalid_share['id'], constants.STATUS_MANAGE_ERROR)
+            )['share']
+            waiters.wait_for_resource_status(
+                self.shares_v2_client, invalid_share['id'],
+                constants.STATUS_MANAGE_ERROR)
 
             # cleanup
             self._unmanage_share_and_wait(invalid_share)
@@ -199,7 +201,8 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
         managed_share = self._manage_share_and_wait(manage_params)
 
         # update managed share's reference
-        managed_share = self.shares_v2_client.get_share(managed_share['id'])
+        managed_share = self.shares_v2_client.get_share(
+            managed_share['id'])['share']
         manage_params = self._get_manage_params_from_share(managed_share)
 
         # the second attempt to manage the same share should fail
@@ -258,11 +261,15 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
 
         # forge bad param to have a share in manage_error state
         invalid_params = valid_params.copy()
-        invalid_params.update({'export_path': 'invalid'})
-        invalid_share = self.shares_v2_client.manage_share(**invalid_params)
+        invalid_params.update(
+            {'export_path': data_utils.rand_name(name='invalid-share-export')}
+        )
+        invalid_share = self.shares_v2_client.manage_share(
+            **invalid_params)['share']
 
-        self.shares_v2_client.wait_for_share_status(
-            invalid_share['id'], constants.STATUS_MANAGE_ERROR)
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, invalid_share['id'],
+            constants.STATUS_MANAGE_ERROR)
         self._unmanage_share_and_wait(share)
 
         # the attempt to delete a share in manage_error should raise an
@@ -295,7 +302,7 @@ class ManageNFSShareNegativeTest(base.BaseSharesAdminTest):
         share = self._create_share_for_manage()
 
         snap = self.create_snapshot_wait_for_active(share["id"])
-        snap = self.shares_v2_client.get_snapshot(snap['id'])
+        snap = self.shares_v2_client.get_snapshot(snap['id'])['snapshot']
 
         self.assertRaises(
             lib_exc.Forbidden,
