@@ -21,6 +21,7 @@ import testtools
 from testtools import testcase as tc
 
 from manila_tempest_tests.tests.api import base
+from manila_tempest_tests import utils
 
 CONF = config.CONF
 
@@ -37,7 +38,11 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
 
         # create share type for share filtering purposes
         specs = {"storage_protocol": CONF.share.capability_storage_protocol}
-        cls.share_type = cls._create_share_type(specs=specs)
+        if CONF.share.capability_snapshot_support:
+            specs.update({'snapshot_support': True})
+        if CONF.share.capability_create_share_from_snapshot_support:
+            specs.update({'create_share_from_snapshot_support': True})
+        cls.share_type = cls.create_share_type(extra_specs=specs)
         cls.share_type_id = cls.share_type['id']
 
         # create share
@@ -86,7 +91,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_get_share(self):
 
         # get share
-        share = self.shares_client.get_share(self.shares[0]['id'])
+        share = self.shares_client.get_share(self.shares[0]['id'])['share']
 
         # verify keys
         expected_keys = ["status", "description", "links", "availability_zone",
@@ -114,7 +119,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares(self):
 
         # list shares
-        shares = self.shares_client.list_shares()
+        shares = self.shares_client.list_shares()['shares']
 
         # verify keys
         keys = ["name", "id", "links"]
@@ -131,7 +136,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_with_detail(self):
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail()
+        shares = self.shares_client.list_shares_with_detail()['shares']
 
         # verify keys
         keys = [
@@ -153,7 +158,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         filters = {'metadata': self.metadata}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -174,7 +180,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         share_type_list = self.shares_client.list_share_types()["share_types"]
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -194,7 +201,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
                     "nonexistent share type '%(st)s'." % {
                         "s_id": share["id"], "st": share["share_type"]}
                 )
-            extra_specs = self.shares_client.get_share_type_extra_specs(st_id)
+            extra_specs = self.shares_client.get_share_type_extra_specs(
+                st_id)['extra_specs']
             self.assertDictContainsSubset(filters["extra_specs"], extra_specs)
 
     @decorators.idempotent_id('76fbe8ba-f1d3-4446-b9b8-55617762a2c7')
@@ -203,7 +211,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         filters = {'share_type_id': self.share_type_id}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -231,18 +240,20 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     @decorators.idempotent_id('04afc330-78ee-494f-a660-7670c877a440')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_list_shares_with_detail_filter_by_host(self):
-        base_share = self.shares_client.get_share(self.shares[0]['id'])
+        base_share = self.shares_client.get_share(
+            self.shares[0]['id'])['share']
         filters = {'host': base_share['host']}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
         for share in shares:
             self.assertEqual(filters['host'], share['host'])
 
-    @base.skip_if_microversion_lt("2.35")
+    @utils.skip_if_microversion_not_supported("2.35")
     @ddt.data(('path', True), ('id', True), ('path', False), ('id', False))
     @ddt.unpack
     @decorators.idempotent_id('a27e5e3f-451f-4200-af38-99a562ccbe86')
@@ -250,7 +261,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_or_with_detail_filter_by_export_location(
             self, export_location_type, enable_detail):
         export_locations = self.shares_v2_client.list_share_export_locations(
-            self.shares[0]['id'])
+            self.shares[0]['id'])['export_locations']
         if not isinstance(export_locations, (list, tuple, set)):
             export_locations = (export_locations, )
 
@@ -261,9 +272,10 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         # list shares
         if enable_detail:
             shares = self.shares_v2_client.list_shares_with_detail(
-                params=filters)
+                params=filters)['shares']
         else:
-            shares = self.shares_v2_client.list_shares(params=filters)
+            shares = self.shares_v2_client.list_shares(
+                params=filters)['shares']
 
         # verify response
         self.assertEqual(1, len(shares))
@@ -274,11 +286,13 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     @testtools.skipIf(
         not CONF.share.multitenancy_enabled, "Only for multitenancy.")
     def test_list_shares_with_detail_filter_by_share_network_id(self):
-        base_share = self.shares_client.get_share(self.shares[0]['id'])
+        base_share = self.shares_client.get_share(
+            self.shares[0]['id'])['share']
         filters = {'share_network_id': base_share['share_network_id']}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -295,7 +309,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         filters = {'snapshot_id': self.snap['id']}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -309,7 +324,8 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
         filters = {'sort_key': 'created_at', 'sort_dir': 'asc'}
 
         # list shares
-        shares = self.shares_client.list_shares_with_detail(params=filters)
+        shares = self.shares_client.list_shares_with_detail(
+            params=filters)['shares']
 
         # verify response
         self.assertGreater(len(shares), 0)
@@ -321,7 +337,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_with_detail_filter_by_existed_name(self):
         # list shares by name, at least one share is expected
         params = {"name": self.share_name}
-        shares = self.shares_client.list_shares_with_detail(params)
+        shares = self.shares_client.list_shares_with_detail(params)['shares']
         self.assertEqual(self.share_name, shares[0]["name"])
 
     @decorators.idempotent_id('d0dae9e5-a826-48e4-b7b7-24b08ad5a7cb')
@@ -329,7 +345,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_with_detail_filter_by_fake_name(self):
         # list shares by fake name, no shares are expected
         params = {"name": data_utils.rand_name("fake-nonexistent-name")}
-        shares = self.shares_client.list_shares_with_detail(params)
+        shares = self.shares_client.list_shares_with_detail(params)['shares']
         self.assertEqual(0, len(shares))
 
     @decorators.idempotent_id('8eac9b63-666f-4c52-8c5f-58b1fdf201e2')
@@ -337,7 +353,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_with_detail_filter_by_active_status(self):
         # list shares by active status, at least one share is expected
         params = {"status": "available"}
-        shares = self.shares_client.list_shares_with_detail(params)
+        shares = self.shares_client.list_shares_with_detail(params)['shares']
         self.assertGreater(len(shares), 0)
         for share in shares:
             self.assertEqual(params["status"], share["status"])
@@ -347,7 +363,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_shares_with_detail_filter_by_fake_status(self):
         # list shares by fake status, no shares are expected
         params = {"status": 'fake'}
-        shares = self.shares_client.list_shares_with_detail(params)
+        shares = self.shares_client.list_shares_with_detail(params)['shares']
         self.assertEqual(0, len(shares))
 
     @decorators.idempotent_id('d24a438e-4622-48ac-993e-a30d04746745')
@@ -357,7 +373,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_get_snapshot(self):
 
         # get snapshot
-        get = self.shares_client.get_snapshot(self.snap["id"])
+        get = self.shares_client.get_snapshot(self.snap["id"])['snapshot']
 
         # verify keys
         expected_keys = ["status", "links", "share_id", "name",
@@ -388,7 +404,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_snapshots(self):
 
         # list share snapshots
-        snaps = self.shares_client.list_snapshots()
+        snaps = self.shares_client.list_snapshots()['snapshots']
 
         # verify keys
         keys = ["id", "name", "links"]
@@ -406,7 +422,7 @@ class SharesActionsAdminTest(base.BaseSharesAdminTest):
     def test_list_snapshots_with_detail(self):
 
         # list share snapshots
-        snaps = self.shares_client.list_snapshots_with_detail()
+        snaps = self.shares_client.list_snapshots_with_detail()['snapshots']
 
         # verify keys
         keys = ["status", "links", "share_id", "name",
