@@ -18,6 +18,7 @@ from tempest.lib import exceptions
 import testtools
 from testtools import testcase as tc
 
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests.tests.scenario import manager_share as manager
 from manila_tempest_tests import utils
@@ -82,20 +83,20 @@ class ShareManageUnmanageBase(manager.ShareScenarioTest):
         remote_client = self.init_remote_client(instance)
 
         LOG.debug('Step 4 - provide access to instance')
-        self.provide_access_to_auxiliary_instance(instance, share=share)
+        self._provide_access_to_client_identified_by_ip(instance, share=share)
 
         if utils.is_microversion_lt(CONF.share.max_api_microversion, "2.9"):
             locations = share['export_locations']
         else:
             exports = self.shares_v2_client.list_share_export_locations(
-                share['id'])
+                share['id'])['export_locations']
             locations = [x['path'] for x in exports]
 
         LOG.debug('Step 5 - mount')
         self.mount_share(locations[0], remote_client)
 
         # Update share info, needed later
-        share = self.shares_admin_v2_client.get_share(share['id'])
+        share = self.shares_admin_v2_client.get_share(share['id'])['share']
 
         LOG.debug('Step 6a - create file')
         remote_client.exec_command("sudo touch /mnt/t1")
@@ -122,7 +123,7 @@ class ShareManageUnmanageBase(manager.ShareScenarioTest):
         self.assertRaises(
             exceptions.NotFound,
             self.shares_admin_v2_client.get_share,
-            self.share['id'])
+            share['id'])
 
         LOG.debug('Step 10 - manage share')
         share_type = self.get_share_type()
@@ -130,18 +131,18 @@ class ShareManageUnmanageBase(manager.ShareScenarioTest):
             share['host'],
             share['share_proto'],
             locations[0],
-            share_type['id'])
-        self.shares_admin_v2_client.wait_for_share_status(
-            managed_share['id'], 'available')
+            share_type['id'])['share']
+        waiters.wait_for_resource_status(
+            self.shares_admin_v2_client, managed_share['id'], 'available')
 
         LOG.debug('Step 11 - grant access again')
-        self.provide_access_to_auxiliary_instance(
+        self._provide_access_to_client_identified_by_ip(
             instance,
             share=managed_share,
             client=self.shares_admin_v2_client)
 
         exports = self.shares_admin_v2_client.list_share_export_locations(
-            managed_share['id'])
+            managed_share['id'])['export_locations']
         locations = [x['path'] for x in exports]
 
         LOG.debug('Step 12 - mount')
@@ -164,9 +165,9 @@ class ShareManageUnmanageBase(manager.ShareScenarioTest):
             share['host'],
             share['share_proto'],
             locations[0],
-            share_type['id'])
-        self.shares_admin_v2_client.wait_for_share_status(
-            remanaged_share['id'], 'manage_error')
+            share_type['id'])['share']
+        waiters.wait_for_resource_status(
+            self.shares_admin_v2_client, remanaged_share['id'], 'manage_error')
 
         self.shares_admin_v2_client.reset_state(remanaged_share['id'])
 
@@ -176,31 +177,14 @@ class ShareManageUnmanageBase(manager.ShareScenarioTest):
             share_id=remanaged_share['id'])
 
 
-class ShareManageUnmanageNFS(ShareManageUnmanageBase):
-    protocol = "nfs"
-
-    def mount_share(self, location, remote_client, target_dir=None):
-
-        self.validate_ping_to_export_location(location, remote_client)
-
-        target_dir = target_dir or "/mnt"
-        remote_client.exec_command(
-            "sudo mount -vt nfs \"%s\" %s" % (location, target_dir)
-        )
+class ShareManageUnmanageNFS(manager.BaseShareScenarioNFSTest,
+                             ShareManageUnmanageBase):
+    pass
 
 
-class ShareManageUnmanageCIFS(ShareManageUnmanageBase):
-    protocol = "cifs"
-
-    def mount_share(self, location, remote_client, target_dir=None):
-
-        self.validate_ping_to_export_location(location, remote_client)
-
-        location = location.replace("\\", "/")
-        target_dir = target_dir or "/mnt"
-        remote_client.exec_command(
-            "sudo mount.cifs \"%s\" %s -o guest" % (location, target_dir)
-        )
+class ShareManageUnmanageCIFS(manager.BaseShareScenarioCIFSTest,
+                              ShareManageUnmanageBase):
+    pass
 
 
 class ShareManageUnmanageNFSIPv6(ShareManageUnmanageNFS):
